@@ -16,7 +16,7 @@ conduct_conditional_ra <-
 
     assignment_vec_new <- assignment_vec
 
-    if (inherits(declaration, "ra_simple") || declaration$ra_type == "simple") {
+    if (inherits(declaration, "ra_simple")) {
       prob_each_local <-
         declaration$probabilities_matrix[1, paste0("prob_", conditions)]
       prob_each_local <- prob_each_local / (sum(prob_each_local))
@@ -31,7 +31,7 @@ conduct_conditional_ra <-
         )
     }
 
-    if (inherits(declaration, "ra_complete") || declaration$ra_type == "complete") {
+    if (inherits(declaration, "ra_complete")) {
       prob_each_local <-
         declaration$probabilities_matrix[1, paste0("prob_", conditions)]
       prob_each_local <- prob_each_local / (sum(prob_each_local))
@@ -45,7 +45,7 @@ conduct_conditional_ra <-
         )
     }
 
-    if (inherits(declaration, "ra_blocked") || declaration$ra_type == "blocked") {
+    if (inherits(declaration, "ra_blocked")) {
       block_prob_each_local <- by(
         declaration$probabilities_matrix,
         INDICES = declaration$blocks,
@@ -66,7 +66,7 @@ conduct_conditional_ra <-
         )
     }
 
-    if (inherits(declaration, "ra_clustered") || declaration$ra_type == "clustered") {
+    if (inherits(declaration, "ra_clustered")) {
       prob_each_local <-
         declaration$probabilities_matrix[1, paste0("prob_", conditions)]
       prob_each_local <- prob_each_local / (sum(prob_each_local))
@@ -80,7 +80,7 @@ conduct_conditional_ra <-
         )
     }
 
-    if (inherits(declaration, "ra_blocked_and_clustered") || declaration$ra_type == "blocked_and_clustered") {
+    if (inherits(declaration, "ra_blocked_and_clustered")) {
       block_prob_each_local <- by(
         declaration$probabilities_matrix,
         INDICES = declaration$blocks,
